@@ -1,4 +1,5 @@
-from .analyzer import note_to_chord
+# flake8: noqa
+from .analyzer import find_chords_from_notes
 from .chord import Chord
 from .progression import ChordProgression
 from .quality import Quality, QualityManager
