@@ -1,6 +1,12 @@
+# Do not import DEFAULT_QUALITIES directly
+# Use QualityManager instead
 DEFAULT_QUALITIES = [
     # chords consist of 2 notes
     ('5', (0, 7)),
+    ('no5', (0, 4)),
+    ('omit5', (0, 4)),
+    ('m(no5)', (0, 3)),
+    ('m(omit5)', (0, 3)),
     # 3 notes
     ('', (0, 4, 7)),
     ('maj', (0, 4, 7)),
@@ -8,6 +14,8 @@ DEFAULT_QUALITIES = [
     ('min', (0, 3, 7)),
     ('-', (0, 3, 7)),
     ('dim', (0, 3, 6)),
+    # Not to confuse Ab5 with A(b5)
+    ('(b5)', (0, 4, 6)),
     ('aug', (0, 4, 8)),
     ('sus2', (0, 2, 7)),
     ('sus4', (0, 5, 7)),
@@ -38,6 +46,8 @@ DEFAULT_QUALITIES = [
     ('add9', (0, 4, 7, 14)),
     ('Madd9', (0, 4, 7, 14)),
     ('madd9', (0, 3, 7, 14)),
+    ('sus4add9', (0, 5, 7, 14)),
+    ('sus4add2', (0, 2, 5, 7)),
     ('2', (0, 4, 7, 14)),
     ('add11', (0, 4, 7, 17)),
     ('4', (0, 4, 7, 17)),
